searchData={"items":[{"type":"module","title":"Kino.MapLibre","doc":"This Kino allows rendering a regular MapLibre map and then adds an initial support for the\n[Evented](https://maplibre.org/maplibre-gl-js-docs/api/events/#evented) API to update the map\nwith event capabilities.\n\nThere are two types of maps: static and dynamic. Essentially, a dynamic map can be updated on\nthe fly without having to be re-evaluated. To make a map dynamic you need to wrap it in `Kino.MapLibre.new/1`\n\nAll functions are available for both map types.","ref":"Kino.MapLibre.html"},{"type":"module","title":"Examples - Kino.MapLibre","doc":"map =\n      Ml.new(center: {-68.13734351262877, 45.137451890638886}, zoom: 3)\n      # This makes the map dynamic\n      |> Kino.MapLibre.new()\n\n    # These markers will be added with no need to re-evaluate the map\n    Kino.MapLibre.add_marker(map, {-68, 45}, color: \"red\", draggable: true)\n    Kino.MapLibre.add_marker(map, {-69, 50})\n\n    # This is a static map and the markers will be added on evaluation\n    Ml.new(center: {-68.13734351262877, 45.137451890638886}, zoom: 3)\n    |> Kino.MapLibre.add_marker({-68, 45}, color: \"red\", draggable: true)\n    |> Kino.MapLibre.add_marker({-69, 50})","ref":"Kino.MapLibre.html#module-examples"},{"type":"function","title":"Kino.MapLibre.add_custom_image/4","doc":"Adds an image to the style. This image can be displayed on the map like any other icon in the\nstyle's sprite using its ID","ref":"Kino.MapLibre.html#add_custom_image/4"},{"type":"function","title":"Kino.MapLibre.add_export_map/2","doc":"Adds a control to exports the map as a PDF or image (PNG, JPEG and SVG).","ref":"Kino.MapLibre.html#add_export_map/2"},{"type":"function","title":"Options - Kino.MapLibre.add_export_map/2","doc":"* `:filename` - The filename without the extension. Default: \"map\"\n\n  * `:printable_area` Display printable area on the map. It helps to adjust printable area before printing.\n\n  * `:crosshair` Display crosshair on the map. It helps to adjust the map center before printing.","ref":"Kino.MapLibre.html#add_export_map/2-options"},{"type":"function","title":"Examples - Kino.MapLibre.add_export_map/2","doc":"Kino.MapLibre.add_export_map(map)\n      Kino.MapLibre.add_export_map(map, crosshair: true)","ref":"Kino.MapLibre.html#add_export_map/2-examples"},{"type":"function","title":"Kino.MapLibre.add_fullscreen_control/1","doc":"Adds a fullscreen control for toggling the map in and out of fullscreen mode.","ref":"Kino.MapLibre.html#add_fullscreen_control/1"},{"type":"function","title":"Examples - Kino.MapLibre.add_fullscreen_control/1","doc":"Kino.MapLibre.add_fullscreen_control(map)","ref":"Kino.MapLibre.html#add_fullscreen_control/1-examples"},{"type":"function","title":"Kino.MapLibre.add_geocode_control/1","doc":"Adds a geocoder control to the map to handle Nominatim queries","ref":"Kino.MapLibre.html#add_geocode_control/1"},{"type":"function","title":"Examples - Kino.MapLibre.add_geocode_control/1","doc":"Kino.MapLibre.add_geocode_control(map)","ref":"Kino.MapLibre.html#add_geocode_control/1-examples"},{"type":"function","title":"Kino.MapLibre.add_hover/2","doc":"A helper function to create a per feature hover effect. Receives the ID of the layer where the\neffect should be enabled. It uses events and feature states to create the effect.","ref":"Kino.MapLibre.html#add_hover/2"},{"type":"function","title":"Examples - Kino.MapLibre.add_hover/2","doc":"Kino.MapLibre.add_hover(map, \"state-fills\")\n\nSee [the docs](https://maplibre.org/maplibre-gl-js-docs/api/map/#map#setfeaturestate) for more\ndetails.","ref":"Kino.MapLibre.html#add_hover/2-examples"},{"type":"function","title":"Kino.MapLibre.add_locate_control/2","doc":"Adds a geolocate control to the map.\n\nA geolocate control provides a button that uses the browser's\ngeolocation API to locate the user on the map.","ref":"Kino.MapLibre.html#add_locate_control/2"},{"type":"function","title":"Options - Kino.MapLibre.add_locate_control/2","doc":"* `:track_user_location` - If true, the geolocate control acts as a toggle button that when\n  active the user's location is actively monitored for changes. Default: `false`\n\n  * `:high_accuracy` - Uses a more accurate position if the device is able to. Default: `false`\n\n  * `:show_user_location` - A dot will be shown on the map at the user's location. Default: `true`\n\n  * `:show_accuracy_circle` - By default, if `:show_user_location` is `true`, a transparent\n  circle will be drawn around the user location indicating the accuracy (95% confidence level)\n  of the user's location. Default: `true`","ref":"Kino.MapLibre.html#add_locate_control/2-options"},{"type":"function","title":"Examples - Kino.MapLibre.add_locate_control/2","doc":"Kino.MapLibre.add_locate_control(map)\n      Kino.MapLibre.add_locate_control(map, high_accuracy: true, track_user_location: true)","ref":"Kino.MapLibre.html#add_locate_control/2-examples"},{"type":"function","title":"Kino.MapLibre.add_marker/3","doc":"Adds a marker to the map at the given location","ref":"Kino.MapLibre.html#add_marker/3"},{"type":"function","title":"Options - Kino.MapLibre.add_marker/3","doc":"* `:element` - DOM element to use as a marker. The default is a light blue, droplet-shaped SVG\n    marker.\n\n  * `:anchor` - A string indicating the part of the Marker that should be positioned closest to\n    the coordinate set via Marker#setLngLat. Options are  \"center\",  \"top\", \"bottom\",  \"left\",\n    \"right\",  \"top-left\",  \"top-right\",  \"bottom-left\" and  \"bottom-right\". Default: \"center\"\n\n  * `:offset` - The offset in pixels as a\n    [PointLike](https://maplibre.org/maplibre-gl-js-docs/api/geography/#pointlike) object to\n    apply relative to the element\"s center. Negatives indicate left and up.\n\n  * `:color` - The color to use for the default marker if `:element` is not provided. The\n    default is light blue. Default: \"#3FB1CE\"\n\n  * `:scale` - The scale to use for the default marker if `:element` is not provided. The\n    default scale corresponds to a height of 41px and a width of 27px. Default: 1\n\n  * `:draggable` - A boolean indicating whether or not a marker is able to be dragged to a new\n    position on the map. Default: `false`\n\n  * `:click_tolerance` - The max number of pixels a user can shift the mouse pointer during a\n    click on the marker for it to be considered a valid click (as opposed to a marker drag). The\n    default is to inherit map\"s `:click_tolerance`. Default: 0\n\n  * `:rotation` - The rotation angle of the marker in degrees, relative to its respective\n    `:rotation_alignment` setting. A positive value will rotate the marker clockwise. Default: 0\n\n  * `:pitch_alignment` - \"map\" aligns the marker to the plane of the map. \"viewport\" aligns the\n    marker to the plane of the viewport. \"auto\" automatically matches the value of\n    `:rotation_alignment`. Default: \"auto\"\n\n  * `:rotation_alignment` - \"map\" aligns the  marker\"s rotation relative to the map, maintaining\n    a bearing as the map rotates. \"viewport\" aligns the  marker\"s rotation relative to the\n    viewport, agnostic to map rotations. \"auto\" is equivalent to viewport. Default: \"auto\"\n\n  See [the docs](https://maplibre.org/maplibre-gl-js-docs/api/markers/#marker) for more details.","ref":"Kino.MapLibre.html#add_marker/3-options"},{"type":"function","title":"Kino.MapLibre.add_markers/2","doc":"Receives a list of markers and adds them to the map","ref":"Kino.MapLibre.html#add_markers/2"},{"type":"function","title":"Examples - Kino.MapLibre.add_markers/2","doc":"markers = [\n      [{0, 0}, color: \"red\", draggable: true],\n      [{-32, 2}, color: \"green\"],\n      [{-45, 23}]\n    ]\n\n    Ml.new(center: {-68.13734351262877, 45.137451890638886}, zoom: 3)\n    |> Kino.MapLibre.add_markers(markers)","ref":"Kino.MapLibre.html#add_markers/2-examples"},{"type":"function","title":"Kino.MapLibre.add_nav_controls/2","doc":"Adds a navigation control to the map. A navigation control contains zoom buttons and a compass.","ref":"Kino.MapLibre.html#add_nav_controls/2"},{"type":"function","title":"Options - Kino.MapLibre.add_nav_controls/2","doc":"* `:show_compass` - If true the compass button is included. Default: `true`\n\n  * `:show_zoom` - If true the zoom-in and zoom-out buttons are included. Default: `true`\n\n  * `:visualize_pitch` - If true the pitch is visualized by rotating X-axis of compass. Default:\n    `false`\n\n  * `:position` - The position on the map to which the control will be added. Valid values are\n    \"top-left\" , \"top-right\" ,  \"bottom-left\" , and  \"bottom-right\" . Defaults to  \"top-right\".\n    Default: \"top-right\"\n\n  You can add multiple controls separately to have granular options over positioning and\n  appearance","ref":"Kino.MapLibre.html#add_nav_controls/2-options"},{"type":"function","title":"Examples - Kino.MapLibre.add_nav_controls/2","doc":"Kino.MapLibre.add_nav_controls(map, show_compass: false)\n      Kino.MapLibre.add_nav_controls(map, show_zoom: false, position: \"top-left\")","ref":"Kino.MapLibre.html#add_nav_controls/2-examples"},{"type":"function","title":"Kino.MapLibre.add_scale_control/2","doc":"Adds a scale control for displaying the ratio of a distance on the map to the corresponding\ndistance on the ground.","ref":"Kino.MapLibre.html#add_scale_control/2"},{"type":"function","title":"Options - Kino.MapLibre.add_scale_control/2","doc":"* `:max_width` - The maximum length of the scale control in pixels. Default: 100\n\n  * `:unit` - Unit of the distance (`:imperial`, `:metric` or ':nautical'). Default: `:metric`","ref":"Kino.MapLibre.html#add_scale_control/2-options"},{"type":"function","title":"Examples - Kino.MapLibre.add_scale_control/2","doc":"Kino.MapLibre.add_scale_control(map)\n      Kino.MapLibre.add_scale_control(map, unit: :nautical)","ref":"Kino.MapLibre.html#add_scale_control/2-examples"},{"type":"function","title":"Kino.MapLibre.add_terrain_control/1","doc":"Adds a terrain control to the map for turning the terrain on and off.","ref":"Kino.MapLibre.html#add_terrain_control/1"},{"type":"function","title":"Examples - Kino.MapLibre.add_terrain_control/1","doc":"Kino.MapLibre.add_terrain_control(map)","ref":"Kino.MapLibre.html#add_terrain_control/1-examples"},{"type":"function","title":"Kino.MapLibre.center_on_click/2","doc":"A helper function that adds the event of centering to coordinates when clicking on a symbol.\nReceives the ID of the symbols layer and adds the event to all the symbols present in that layer","ref":"Kino.MapLibre.html#center_on_click/2"},{"type":"function","title":"Kino.MapLibre.clusters_expansion/2","doc":"A helper function to allow inspect a cluster on click. Receives the ID of the clusters layer","ref":"Kino.MapLibre.html#clusters_expansion/2"},{"type":"function","title":"Examples - Kino.MapLibre.clusters_expansion/2","doc":"Kino.MapLibre.clusters_expansion(map, \"earthquakes-clusters\")","ref":"Kino.MapLibre.html#clusters_expansion/2-examples"},{"type":"function","title":"Kino.MapLibre.fit_bounds/3","doc":"Fits the map to the rectangle given by the 2 vertices in `bounds`","ref":"Kino.MapLibre.html#fit_bounds/3"},{"type":"function","title":"Kino.MapLibre.info_on_click/3","doc":"A helper function that adds the event to show the information of a given property on click.\nReceives the layer ID and the name of the property to show.","ref":"Kino.MapLibre.html#info_on_click/3"},{"type":"function","title":"Kino.MapLibre.jump_to/3","doc":"Jumps to a given location using an animated transition","ref":"Kino.MapLibre.html#jump_to/3"},{"type":"function","title":"Kino.MapLibre.new/1","doc":"Creates a new kino with the given MapLibre style.","ref":"Kino.MapLibre.html#new/1"},{"type":"type","title":"Kino.MapLibre.location/0","doc":"","ref":"Kino.MapLibre.html#t:location/0"},{"type":"type","title":"Kino.MapLibre.maplibre/0","doc":"","ref":"Kino.MapLibre.html#t:maplibre/0"},{"type":"type","title":"Kino.MapLibre.t/0","doc":"","ref":"Kino.MapLibre.html#t:t/0"},{"type":"extras","title":"Components","doc":"# Components\n\n```elixir\nMix.install([\n  {:maplibre, \"~> 0.1.9\"},\n  {:kino_maplibre, \"~> 0.1.13\"},\n  {:req, \"~> 0.3.1\"}\n])\n\nalias MapLibre, as: Ml\n```","ref":"components.html"},{"type":"extras","title":"Kinos - Components","doc":"#","ref":"components.html#kinos"},{"type":"extras","title":"MapLibre - Components","doc":"This integration automatically renders the `MapLibre` struct as a map:\n\n```elixir\nMl.new(\n  center: {-90.73414, 14.55524},\n  zoom: 13,\n  style: \"https://api.maptiler.com/maps/basic/style.json?key=Q4UbchekCfyvXvZcWRoU\"\n)\n|> Ml.update_layer(\"building\",\n  paint: [\n    fill_color: [\"interpolate\", [\"exponential\", 0.5], [\"zoom\"], 15, \"#e2714b\", 22, \"#eee695\"],\n    fill_opacity: [\"interpolate\", [\"exponential\", 0.5], [\"zoom\"], 15, 0, 22, 1]\n  ]\n)\n```\n\n#","ref":"components.html#maplibre"},{"type":"extras","title":"Kino.MapLibre - Components","doc":"`Kino.MapLibre` allows you to render a regular `MapLibre` map and then adds an initial support for the [Evented](https://maplibre.org/maplibre-gl-js-docs/api/events/#evented) API to update the map.\n\nThere are two types of maps: static and dynamic. Essentially, a dynamic map can be updated on\nthe fly without having to be re-evaluated. To make a map dynamic you need to wrap it in `Kino.MapLibre.new/1`:\n\n```elixir\nmap =\n  Ml.new(center: {-68.13734351262877, 45.137451890638886}, zoom: 3)\n  |> Kino.MapLibre.new()\n```\n\nHaving our dynamic map, we can now add new markers to the map at any point:\n\n```elixir\nKino.MapLibre.add_marker(map, {-69, 50})\nKino.MapLibre.add_marker(map, {-68, 45}, color: \"red\", draggable: true)\n```\n\nAll manipulation functions are available for the static map as well. We just\nneed to build it at once:\n\n```elixir\nMl.new(center: {-68.13734351262877, 45.137451890638886}, zoom: 3)\n|> Kino.MapLibre.add_marker({-68, 45}, color: \"red\", draggable: true)\n|> Kino.MapLibre.add_marker({-69, 50})\n```\n\nYou can make a static map dynamic at any moment wrapping it in `Kino.MapLibre.new/1`\n\n```elixir\nmap =\n  Ml.new(center: {-68.13734351262877, 45.137451890638886}, zoom: 3)\n  # These markers will appear on the initial map render\n  |> Kino.MapLibre.add_marker({-68, 45}, color: \"red\", draggable: true)\n  |> Kino.MapLibre.add_marker({-69, 50})\n  # This makes the map dynamic for further interactions\n  |> Kino.MapLibre.new()\n```\n\nLet's add navigation controls on the fly!\n\n```elixir\nKino.MapLibre.add_nav_controls(map)\n```","ref":"components.html#kino-maplibre"},{"type":"extras","title":"Smart cells - Components","doc":"The following Smart cells are available:\n\n* **Map cell** - for building maps with geojson data","ref":"components.html#smart-cells"}],"content_type":"text/markdown"}